<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => '000000',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/sukha-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'sukha_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'sukha_remove_parent_dynamic_css' );
	function sukha_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'sukha_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'sukha_enqueue_parent_dynamic_css', 50 );
	function sukha_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'sukha_customize_register' ) ) {
	add_action( 'customize_register', 'sukha_customize_register' );
	function sukha_customize_register( $wp_customize ) {
				
		// Add Sukha customizer section
		$wp_customize->add_section(
			'sukha_layout_effects',
			array(
				'title' => __( 'Sukha Effects', 'sukha' ),
				'priority' => 1,
				'panel' => 'lalita_layout_panel'
			)
		);
		
		// Navigation border
		$wp_customize->add_setting(
			'sukha_settings[nav_border]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sukha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[nav_border]',
			array(
				'type' => 'select',
				'label' => __( 'Sukha navigation border', 'sukha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sukha' ),
					'disable' => __( 'Disable', 'sukha' )
				),
				'settings' => 'sukha_settings[nav_border]',
				'section' => 'sukha_layout_effects',
				'priority' => 1
			)
		);
		
		// Footer widgets
		$wp_customize->add_setting(
			'sukha_settings[footer_widgets]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sukha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[footer_widgets]',
			array(
				'type' => 'select',
				'label' => __( 'Sukha footer widgets', 'sukha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sukha' ),
					'disable' => __( 'Disable', 'sukha' )
				),
				'settings' => 'sukha_settings[footer_widgets]',
				'section' => 'sukha_layout_effects',
				'priority' => 1
			)
		);
		
		// Nicescroll
		$wp_customize->add_setting(
			'sukha_settings[nicescroll]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sukha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[nicescroll]',
			array(
				'type' => 'select',
				'label' => __( 'Scrollbar style', 'sukha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sukha' ),
					'disable' => __( 'Disable', 'sukha' )
				),
				'settings' => 'sukha_settings[nicescroll]',
				'section' => 'sukha_layout_effects',
				'priority' => 20
			)
		);
		
		// Cursor
		$wp_customize->add_setting(
			'sukha_settings[cursor]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sukha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[cursor]',
			array(
				'type' => 'select',
				'label' => __( 'Cursor image', 'sukha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sukha' ),
					'disable' => __( 'Disable', 'sukha' )
				),
				'settings' => 'sukha_settings[cursor]',
				'section' => 'sukha_layout_effects',
				'priority' => 20
			)
		);
		
		// Add navigation extra button text
		$wp_customize->add_setting(
			'sukha_settings[nav_btn_text]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[nav_btn_text]',
			array(
				'type' => 'text',
				'label' => __( 'Extra button text', 'sukha' ),
				'section' => 'lalita_layout_navigation',
				'settings' => 'sukha_settings[nav_btn_text]',
				'priority' => 25
			)
		);
		
		// Add navigation extra button url
		$wp_customize->add_setting(
			'sukha_settings[nav_btn_url]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'esc_url'
			)
		);

		$wp_customize->add_control(
			'sukha_settings[nav_btn_url]',
			array(
				'type' => 'text',
				'label' => __( 'Extra button URL', 'sukha' ),
				'section' => 'lalita_layout_navigation',
				'settings' => 'sukha_settings[nav_btn_url]',
				'priority' => 25
			)
		);
	}
}

//Sanitize choices.
if ( ! function_exists( 'sukha_sanitize_choices' ) ) {
	function sukha_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'sukha_body_classes' ) ) {
	add_filter( 'body_class', 'sukha_body_classes' );
	function sukha_body_classes( $classes ) {
		// Get Customizer settings
		$sukha_settings = get_option( 'sukha_settings' );
		
		$nav_border  	 = 'enable';
		$footer_widgets  = 'enable';
		$nicescroll  	 = 'enable';
		$cursor			 = 'enable';
		
		if ( isset( $sukha_settings['nav_border'] ) ) {
			$nav_border = $sukha_settings['nav_border'];
		}
		
		if ( isset( $sukha_settings['footer_widgets'] ) ) {
			$footer_widgets = $sukha_settings['footer_widgets'];
		}
		
		if ( isset( $sukha_settings['nicescroll'] ) ) {
			$nicescroll = $sukha_settings['nicescroll'];
		}
		
		if ( isset( $sukha_settings['cursor'] ) ) {
			$cursor = $sukha_settings['cursor'];
		}
		
		// Navigation border
		if ( $nav_border != 'disable' ) {
			$classes[] = 'sukha-nav-border';
		}
		
		// Footer widgets
		if ( $footer_widgets != 'disable' ) {
			$classes[] = 'sukha-footer-widgets';
		}
		
		// Scrollbar style function
		if ( $nicescroll != 'disable' ) {
			$classes[] = 'sukha-scrollbar-style';
		}
		
		// Mouse style function
		if ( $cursor != 'disable' ) {
			$classes[] = 'sukha-cursor-style';
		}
		
		return $classes;
	}
}

// Enqueue scripts
if ( ! function_exists( 'sukha_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'sukha_scripts' );
	function sukha_scripts() {
		
		$sukha_settings = get_option( 'sukha_settings' );
		$cursor		 = 'enable';
		if ( isset( $sukha_settings['cursor'] ) ) {
			$cursor = $sukha_settings['cursor'];
		}
		
		if ( $cursor != 'disable' ) {
			wp_enqueue_style( 'sukha-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/css/magic-mouse.min.css", false, LALITA_VERSION, 'all' );
			wp_enqueue_script( 'sukha-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/js/magic-mouse.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
	}
}

// Add the extra button to the navigation.
if ( ! function_exists( 'sukha_navigation_button' ) ) {
	add_filter( 'wp_nav_menu_items', 'sukha_navigation_button', 11, 2 );
	function sukha_navigation_button( $nav, $args ) {
		// Get Customizer settings
		$sukha_settings = get_option( 'sukha_settings' );
		
		// If our primary menu is set, add the extra button.
		if ( ( isset( $sukha_settings['nav_btn_url'] ) ) && ( isset( $sukha_settings['nav_btn_text'] ) ) && ( isset( $args->theme_location ) ) ) {
			if ( ( $args->theme_location == 'primary' ) && ( $sukha_settings['nav_btn_url'] != '' ) ) {
				return $nav . '<li class="wpkoi-nav-btn-h"><a class="wpkoi-nav-btn button" href="' . esc_url( $sukha_settings['nav_btn_url'] ) . '">' . esc_html( $sukha_settings['nav_btn_text'] ) . '</a></li>';
			}
		}
		
	    return $nav;
	}
}
